@@ -171,6 +171,8 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
             ('url', 'url2'),
             ('dob', 'sex', 'spouse'),
             ('hide_in_search', 'hide_address', 'hide_email', 'hide_phone'),
+            ('address_2', 'address2_2'),
+            ('city_2', 'state_2', 'zipcode_2', 'country_2'),
         )}
     )
 
@@ -210,6 +212,16 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         )}
     )
 
+    education = (
+        _('Education History'),
+        {'fields': (
+            ('school1', 'major1', 'degree1', 'graduation_dt1'),
+            ('school2', 'major2', 'degree2', 'graduation_dt2'),
+            ('school3', 'major3', 'degree3', 'graduation_dt3'),
+            ('school4', 'major4', 'degree4', 'graduation_dt4'),
+        )}
+    )
+
     money = (
         _('Money'),
         {'fields': (
@@ -238,6 +250,7 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
     fieldsets = (
         profile,
         membership,
+        education,
         money,
         status
     )
@@ -283,7 +296,8 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
                            )
         fieldsets = (
                 self.profile,
-                self.membership,)
+                self.membership,
+                self.education,)
         if demographics_fields:
             fieldsets += (
                 demographics,
