@@ -28,6 +28,7 @@ def generate_admin_email_body(entry, form_for_form):
 
     return output
 
+
 def generate_submitter_email_body(entry, form_for_form):
     """
         Generates the email body so that is readable
@@ -43,6 +44,7 @@ def generate_submitter_email_body(entry, form_for_form):
 
     return output
 
+
 def generate_email_subject(form, form_entry):
     """
         Generates email subject from subject template
@@ -61,15 +63,15 @@ def generate_email_subject(form, form_entry):
             else:
                 p = re.compile('\[%s\]' % label, re.IGNORECASE)
             subject = p.sub(value, subject)
-            
+
         # title
         p = re.compile('\[title\]', re.IGNORECASE)
         subject = p.sub(form.title, subject)
-            
+
         # replace those brackets with blank string
         p = re.compile('(-\s+)?\[[\d\D\s\S\w\W]*?\]')
         subject = p.sub('', subject)
-    
+
     else:
         subject = "%s:" % (form.title)
         if form_entry.get_first_name():
@@ -82,9 +84,9 @@ def generate_email_subject(form, form_entry):
             subject = "%s - %s" % (subject, form_entry.get_phone_number())
         if form_entry.get_email_address():
             subject = "%s - %s" % (subject, form_entry.get_email_address())
-        
+
     return subject
-    
+
 
 def make_invoice_for_entry(entry, **kwargs):
     """
@@ -92,7 +94,6 @@ def make_invoice_for_entry(entry, **kwargs):
     """
 
     price = entry.pricing.price or kwargs.get('custom_price')
-    price = unicode(price)
     now = datetime.now()
 
     inv = Invoice()
@@ -104,12 +105,21 @@ def make_invoice_for_entry(entry, **kwargs):
     inv.balance = price
     inv.due_date = now
     inv.ship_date = now
-    
+
+    tax = 0
+    if entry.pricing and entry.pricing.taxable:
+        tax = price * entry.pricing.tax_rate
+        total = tax + price
+        inv.tax = tax
+        inv.subtotal = total
+        inv.total = total
+        inv.balance = total
+
     if entry.creator and not entry.creator.is_anonymous():
         inv.set_owner(entry.creator)
 
     inv.save()
-    
+
     return inv
 
 def update_invoice_for_entry(invoice, form):
@@ -134,4 +144,3 @@ def update_invoice_for_entry(invoice, form):
     inv.estimate = True
     inv.status_detail = 'estimate'
     inv.save()
-
